#!/bin/csh -f

## Set Debug Parameter 
# DEBUG=1; erase all temporary files 
#       0; leave all temporary files 
set DEBUG=1
 
## Parameters for Photometry
# Radius within which detect object to do photometry
set PHOTRADIUS=100
# Radius of annulus to measure sky
set PHOTAN=10
# Width of annulus to measure sky
set PHOTDAN=10

if ( $#argv != 1 ) then
    echo "Usage : "$0" (FITS file)"
    exit 1
endif

set FITSFILE=$1

set TMPFILELIST=tmpfile.list
if( -f $TMPFILELIST ) then
  \rm $TMPFILELIST
endif

set CLLOG=log/cl`date +%y%m%d%H%M%S`.log
set CLCOM=cl.com

echo $CLCOM >> $TMPFILELIST

if( !(-e log) ) then
  mkdir log
endif
if( -f $CLLOG ) then
  rm $CLLOG
endif

echo "IRAF Log of $0 $1 $2 $3" > $CLLOG

echo "IRAF log will be written in $CLLOG"

#datapars
echo scale,r,h,1.,0. > tmpdata.par
echo fwhmpsf,r,h,10,0. >> tmpdata.par
echo emission,b,h,yes >> tmpdata.par
echo sigma,r,h,INDEF >> tmpdata.par
echo datamin,r,h,INDEF >> tmpdata.par
echo datamax,r,h,INDEF >> tmpdata.par
echo noise,s,h,\"poisson\" >> tmpdata.par
echo ccdread,s,h,\"\" >> tmpdata.par
echo gain,s,h,\"GAIN\" >> tmpdata.par
echo readnoise,r,h,15 >> tmpdata.par
echo epadu,r,h,1 >> tmpdata.par
echo exposure,s,h,\"EXPTIME\" >> tmpdata.par
echo airmass,s,h,\"AIRMASS\" >> tmpdata.par
echo filter,s,h,\"FILTER01\" >> tmpdata.par
echo obstime,s,h,\"\" >> tmpdata.par
echo itime,r,h,1. >> tmpdata.par
echo xairmass,r,h,INDEF >> tmpdata.par
echo ifilter,s,h,INDEF >> tmpdata.par
echo otime,s,h,INDEF >> tmpdata.par

#centerpars
echo calgorithm,s,h,\"none\" > tmpcenter.par
echo cbox,r,h,5 >> tmpcenter.par
echo cthreshold,r,h,0 >> tmpcenter.par
echo minsnratio,r,h,1.,0 >> tmpcenter.par
echo cmaxiter,i,h,10 >> tmpcenter.par
echo maxshift,r,h,1 >> tmpcenter.par
echo clean,b,h,no >> tmpcenter.par
echo rclean,r,h,1 >> tmpcenter.par
echo rclip,r,h,2. >> tmpcenter.par
echo kclean,r,h,3 >> tmpcenter.par
echo mkcenter,b,h,no >> tmpcenter.par

#fitskypars
echo salgorithm,s,h,\"mode\" > tmpfitsky.par
echo annulus,r,h,RADAN >> tmpfitsky.par
echo dannulus,r,h,$PHOTDAN >> tmpfitsky.par
echo skyvalue,r,h,0. >> tmpfitsky.par
echo smaxiter,i,h,10 >> tmpfitsky.par
echo sloclip,r,h,0. >> tmpfitsky.par
echo shiclip,r,h,0. >> tmpfitsky.par
echo snreject,i,h,50 >> tmpfitsky.par
echo sloreject,r,h,3. >> tmpfitsky.par
echo shireject,r,h,3. >> tmpfitsky.par
echo khist,r,h,3. >> tmpfitsky.par
echo binsize,r,h,0.1 >> tmpfitsky.par
echo smooth,b,h,no >> tmpfitsky.par
echo rgrow,r,h,0. >> tmpfitsky.par
echo mksky,b,h,no >> tmpfitsky.par

#photpars
echo weighting,s,h,\"constant\" > tmpphot.par
echo apertures,s,h,RADAP >> tmpphot.par
echo zmag,r,h,25. >> tmpphot.par
echo mkapert,b,h,no >> tmpphot.par

echo tmpphot.par >> $TMPFILELIST
echo tmpdata.par >> $TMPFILELIST
echo tmpfitsky.par >> $TMPFILELIST
echo tmpcenter.par >> $TMPFILELIST
echo tmpphot2.par >> $TMPFILELIST
echo tmpfitsky2.par >> $TMPFILELIST

set TMPPHOT=tmp.phot
set TMPPHOT2=tmp2.phot
set COORDBASE=base.coo
set COORDOBJ=object.coo
echo $TMPPHOT >> $TMPFILELIST
echo $TMPPHOT2 >> $TMPFILELIST
echo $TMPPHOT2.com >> $TMPFILELIST
echo $COORDBASE >> $TMPFILELIST
echo $COORDOBJ >> $TMPFILELIST


echo "### Photometry ###"
echo "### Photometry ###" >> $CLLOG

echo "# Object Selection #"
echo "# Object Selection #" >> $CLLOG
echo "clickexam "$FITSFILE $COORDOBJ> $CLCOM
echo "logout" >> $CLCOM
cat $CLCOM | cl
# >>& $CLLOG  

set XCENTER=`gawk '{print($1)}' $COORDOBJ`
set YCENTER=`gawk '{print($2)}' $COORDOBJ`

gawk '{print($1,$2,"-1 1 -1 -1 "NR)} ' $COORDOBJ > $COORDBASE

echo "display "$FITSFILE" 1 fi+" > $CLCOM
echo "tvmark 1 $COORDBASE number+" >> $CLCOM
echo "logout" >>& $CLLOG 
cat $CLCOM | cl >>& $CLLOG   

echo "# Aperture Photometry in Process ... #"
echo "# Aperture Photometry in Process ... #" >> $CLLOG

set COORDFILE=$COORDBASE
set filename=$FITSFILE
  set APERTURE=5
  @ ANNULUS = $APERTURE + $PHOTAN
  sed "s/RADAP/$APERTURE/g" tmpphot.par > tmpphot2.par
  sed "s/RADAN/$ANNULUS/g" tmpfitsky.par > tmpfitsky2.par
  if ( -f $TMPPHOT ) then
    \rm $TMPPHOT
  endif
  echo "noao" > $CLCOM 
  echo "digiphot" >> $CLCOM 
  echo "apphot" >> $CLCOM
  echo "phot $filename coords=$COORDFILE output=$TMPPHOT interac- verify- fitskyp=tmpfitsky2.par photpars=tmpphot2.par datapars=tmpdata.par centerpars=tmpcenter.par" >> $CLCOM
  echo "logout" >> $CLCOM
  cat $CLCOM | cl >>& $CLLOG
  sed '/^#/d' $TMPPHOT | gawk 'BEGIN{i=1}{j=NR%5;if(j==3)printf("%s %s ",$2,$4);if(j==0){print($1,$3,$2);i++}}' > $TMPPHOT2

sed '/^#/d' $TMPPHOT | gawk -v conv=3.5 'BEGIN{i=1}{j=NR%5;if(j==1)printf("%d ",i);if(j==4){printf("%s %s %.2f\n",$1,$3,conv);i++}}' > $TMPPHOT2.com

#1   2    3      4      5      6    7         8    9
#id itime filter epadu, stddev nsky aperture area flux
#error=sqrt(flux/epadu+area*stddev*stddev+area*area*stddev*stddev/nsky)
paste $TMPPHOT2.com $TMPPHOT2 | gawk '{flux=$9;error=sqrt($9/$4+$8*$5*$5+$8*$8*$5*$5/$6);print("FLUX="flux,"Error="error,"S/N="flux/error)}'

#echo "### $0 Finished ###"
#echo "### $0 Finished ###" >> $CLLOG
#echo "IRAF log written in $CLLOG"
if ( $DEBUG == 1 ) then
  foreach filename (`cat $TMPFILELIST`)
#    if ( -f $filename ) then
      \rm $filename
#    endif
  end
endif

